@@ -1,11 +1,24 @@
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
-from typing import Optional
+from __future__ import annotations
+from typing import Optional, List, TYPE_CHECKING
+from enum import Enum
+
+if TYPE_CHECKING:
+    from mozanalysis.experiment import TimeLimits
 
 import attr
+import logging
 
-from mozanalysis.experiment import AnalysisBasis
+logger = logging.getLogger(__name__)
+
+
+class AnalysisBasis(Enum):
+    """Determines what the population used for the analysis will be based on."""
+
+    ENROLLMENTS = "enrollments"
+    EXPOSURES = "exposures"
 
 
 @attr.s(frozen=True, slots=True)
@@ -85,7 +98,7 @@ class DataSource:
         return self._from_expr.format(dataset=effective_dataset)
 
     @property
-    def experiments_column_expr(self):
+    def experiments_column_expr(self) -> str:
         if self.experiments_column_type is None:
             return ""
 
@@ -118,13 +131,13 @@ class DataSource:
 
     def build_query(
         self,
-        metric_list,
-        time_limits,
-        experiment_slug,
-        from_expr_dataset=None,
-        analysis_basis=AnalysisBasis.ENROLLMENTS,
+        metric_list: List[Metric],
+        time_limits: TimeLimits,
+        experiment_slug: str,
+        from_expr_dataset: Optional[str] = None,
+        analysis_basis: str = AnalysisBasis.ENROLLMENTS,
         exposure_signal=None,
-    ):
+    ) -> str:
         """Return a nearly-self contained SQL query.
 
         This query does not define ``enrollments`` but otherwise could
@@ -154,8 +167,8 @@ class DataSource:
             e.exposure_date,
             e.analysis_window_start,
             e.analysis_window_end""".format(
-            client_id=self.client_id_column,
-            submission_date=self.submission_date_column,
+            client_id=self.client_id_column or "client_id",
+            submission_date=self.submission_date_column or "submission_date",
             from_expr=self.from_expr_for(from_expr_dataset),
             fddr=time_limits.first_date_data_required,
             lddr=time_limits.last_date_data_required,
@@ -169,12 +182,71 @@ class DataSource:
             if analysis_basis == AnalysisBasis.EXPOSURES and exposure_signal is None
             else "enrollment_date",
             ignore_pre_enroll_first_day=self.experiments_column_expr.format(
-                submission_date=self.submission_date_column,
+                submission_date=self.submission_date_column or "submission_date",
                 experiment_slug=experiment_slug,
             ),
         )
 
-    def get_sanity_metrics(self, experiment_slug):
+    def build_query_targets(
+        self,
+        metric_list: List[Metric],
+        time_limits: TimeLimits,
+        experiment_name: str,
+        analysis_length: int,
+        from_expr_dataset: Optional[str] = None,
+        continuous_enrollment: bool = False,
+    ) -> str:
+        """Return a nearly-self contained SQL query that constructs
+        the metrics query for targeting historical data without
+        an associated experiment slug.
+
+        This query does not define ``targets`` but otherwise could
+        be executed to query all metrics from this data source.
+        """
+        return """
+        SELECT
+            t.client_id,
+            t.enrollment_date,
+            t.analysis_window_start,
+            t.analysis_window_end,
+            {metrics}
+        FROM targets t
+            LEFT JOIN {from_expr} ds
+                ON ds.{client_id} = t.client_id
+                {date_clause}
+        GROUP BY
+            t.client_id,
+            t.enrollment_date,
+            t.analysis_window_start,
+            t.analysis_window_end""".format(
+            client_id=self.client_id_column or "client_id",
+            from_expr=self.from_expr_for(from_expr_dataset),
+            metrics=",\n            ".join(
+                "{se} AS {n}".format(
+                    se=m.select_expr.format(experiment_name=experiment_name), n=m.name
+                )
+                for m in metric_list
+            ),
+            date_clause="""
+        AND ds.{submission_date} BETWEEN '{fddr}' AND '{lddr}'
+        AND ds.{submission_date} BETWEEN
+            DATE_ADD(t.enrollment_date, interval t.analysis_window_start day) AND
+            DATE_ADD(t.enrollment_date, interval t.analysis_window_end day)""".format(
+                submission_date=self.submission_date_column or "submission_date",
+                fddr=time_limits.first_date_data_required,
+                lddr=time_limits.last_date_data_required,
+            )
+            if not continuous_enrollment
+            else """AND ds.{submission_date} BETWEEN
+            t.enrollment_date AND
+            DATE_ADD(t.enrollment_date, interval {analysis_length} day)
+            """.format(
+                submission_date=self.submission_date_column or "submission_date",
+                analysis_length=analysis_length,
+            ),
+        )
+
+    def get_sanity_metrics(self, experiment_slug: str) -> List[Metric]:
         if self.experiments_column_type is None:
             return []
 
@@ -280,18 +352,21 @@ class Metric:
     bigger_is_better = attr.ib(type=bool, default=True)
 
 
-def agg_sum(select_expr):
+def agg_sum(select_expr: str) -> str:
     """Return a SQL fragment for the sum over the data, with 0-filled nulls."""
+    logger.warning("The use of mozanalysis.metrics.agg_sum() is deprecated")
     return "COALESCE(SUM({}), 0)".format(select_expr)
 
 
-def agg_any(select_expr):
+def agg_any(select_expr: str) -> str:
     """Return the logical OR, with FALSE-filled nulls."""
+    logger.warning("The use of mozanalysis.metrics.agg_any() is deprecated")
     return "COALESCE(LOGICAL_OR({}), FALSE)".format(select_expr)
 
 
-def agg_histogram_mean(select_expr):
+def agg_histogram_mean(select_expr: str) -> str:
     """Produces an expression for the mean of an unparsed histogram."""
+    logger.warning("The use of mozanalysis.metrics.agg_histogram_mean() is deprecated")
     return f"""SAFE_DIVIDE(
                 SUM(CAST(JSON_EXTRACT_SCALAR({select_expr}, "$.sum") AS int64)),
                 SUM((SELECT SUM(value) FROM UNNEST(mozfun.hist.extract({select_expr}).values)))
