@@ -35,22 +35,15 @@ def test_resample_and_agg_once_multistat(stack_depth=0):
         test_resample_and_agg_once_multistat(stack_depth + 1)
 
 
-def test_resample_and_agg_once_bcast(spark_context):
-    b_data = spark_context.broadcast(np.array([3.0, 3.0, 3.0]))
-    assert mafsb._resample_and_agg_once_bcast(b_data, np.mean, 42) == 3.0
-
-
-def test_get_bootstrap_samples(spark_context_or_none):
-    res = mafsb.get_bootstrap_samples(
-        np.array([3.0, 3.0, 3.0]), num_samples=2, sc=spark_context_or_none
-    )
+def test_get_bootstrap_samples():
+    res = mafsb.get_bootstrap_samples(np.array([3.0, 3.0, 3.0]), num_samples=2)
     assert res.shape == (2,)
 
     assert res[0] == 3.0
     assert res[1] == 3.0
 
 
-def test_get_bootstrap_samples_multistat(spark_context_or_none, stack_depth=0):
+def test_get_bootstrap_samples_multistat(stack_depth=0):
     data = np.concatenate([np.zeros(10000), np.ones(10000)])
     res = mafsb.get_bootstrap_samples(
         data,
@@ -60,7 +53,6 @@ def test_get_bootstrap_samples_multistat(spark_context_or_none, stack_depth=0):
             "mean": np.mean(x),
         },
         num_samples=2,
-        sc=spark_context_or_none,
     )
 
     assert res.shape == (2, 3)
@@ -77,13 +69,13 @@ def test_get_bootstrap_samples_multistat(spark_context_or_none, stack_depth=0):
         assert (res["mean"] != np.mean(data)).any()  # Extremely unlikely
     elif (res["mean"] == np.mean(data)).any():
         # Re-roll the dice a few times to make sure this was a fluke.
-        test_get_bootstrap_samples_multistat(spark_context_or_none, stack_depth + 1)
+        test_get_bootstrap_samples_multistat(stack_depth + 1)
 
 
-def test_bootstrap_one_branch(spark_context_or_none):
+def test_bootstrap_one_branch():
     data = np.concatenate([np.zeros(10000), np.ones(10000)])
     res = mafsb.bootstrap_one_branch(
-        data, num_samples=100, summary_quantiles=(0.5, 0.61), sc=spark_context_or_none
+        data, num_samples=100, summary_quantiles=(0.5, 0.61)
     )
 
     assert res["mean"] == pytest.approx(0.5, rel=1e-1)
@@ -91,7 +83,7 @@ def test_bootstrap_one_branch(spark_context_or_none):
     assert res["0.61"] == pytest.approx(0.5, rel=1e-1)
 
 
-def test_bootstrap_one_branch_multistat(spark_context_or_none):
+def test_bootstrap_one_branch_multistat():
     data = np.concatenate([np.zeros(10000), np.ones(10000), [1e20]])
     res = mafsb.bootstrap_one_branch(
         data,
@@ -102,7 +94,6 @@ def test_bootstrap_one_branch_multistat(spark_context_or_none):
         num_samples=5,
         summary_quantiles=(0.5, 0.61),
         threshold_quantile=0.9999,
-        sc=spark_context_or_none,
     )
 
     assert res.shape == (2, 3)
@@ -115,7 +106,7 @@ def test_bootstrap_one_branch_multistat(spark_context_or_none):
     assert res.loc["mean", "0.61"] == pytest.approx(0.5, rel=1e-1)
 
 
-def test_compare_branches(spark_context_or_none):
+def test_compare_branches():
     data = pd.DataFrame(
         index=range(60000),
         columns=["branch", "val"],
@@ -133,7 +124,7 @@ def test_compare_branches(spark_context_or_none):
     assert data.val[data.branch != "bigger"].mean() == 0.5
     assert data.val[data.branch == "bigger"].mean() == pytest.approx(0.75)
 
-    res = mafsb.compare_branches(data, "val", num_samples=2, sc=spark_context_or_none)
+    res = mafsb.compare_branches(data, "val", num_samples=2)
 
     assert res["individual"]["control"]["mean"] == pytest.approx(0.5, rel=1e-1)
     assert res["individual"]["same"]["mean"] == pytest.approx(0.5, rel=1e-1)
@@ -154,7 +145,7 @@ def test_compare_branches(spark_context_or_none):
     )
 
 
-def test_compare_branches_multistat(spark_context_or_none):
+def test_compare_branches_multistat():
     data = pd.DataFrame(
         index=range(60000),
         columns=["branch", "val"],
@@ -180,7 +171,6 @@ def test_compare_branches_multistat(spark_context_or_none):
             "mean": np.mean(x),
         },
         num_samples=2,
-        sc=spark_context_or_none,
     )
 
     assert res["individual"]["control"].loc["mean", "mean"] == pytest.approx(
